@@ -155,8 +155,7 @@ exports.init = function (sbot, opts) {
   api.getIndexCounts = function (cb) {
     awaitSync(function () {
       var counts = {
-        // inbox: state.inbox.rows.length, DISABLED
-        // inboxUnread: state.inbox.filter(function (row) { return !row.isread }).length
+        inboxUnread: state.inbox.filter(function (row) { return !row.isread }).length,
         bookmarkUnread: state.bookmarks.filter(function (row) { return !row.isread }).length,
         mentionUnread: state.mentions.filter(function (row) { return !row.isread }).length,
         privateUnread: state.privatePosts.filter(function (row) { return !row.isread }).length,
@@ -219,11 +218,11 @@ exports.init = function (sbot, opts) {
 
   api.markRead = function (key, cb) {
     awaitSync(function () {
-      // indexMarkRead('inbox', key) DISABLED
-      indexMarkRead('bookmarks', key)
-      indexMarkRead('mentions', key)
-      indexMarkRead('privatePosts', key)
-      indexMarkRead('follows', key)
+      indexMarkRead('inbox', key)
+      // indexMarkRead('bookmarks', key)
+      // indexMarkRead('mentions', key)
+      // indexMarkRead('privatePosts', key)
+      // indexMarkRead('follows', key)
       if (Array.isArray(key)) {
         db.isread.batch(key.map(function (k) { return { type: 'put', key: k, value: 1 }}), cb)
         key.forEach(function (key) { emit('isread', { key: key, value: true }) })
@@ -235,11 +234,11 @@ exports.init = function (sbot, opts) {
   }
   api.markUnread = function (key, cb) {
     awaitSync(function () {
-      // indexMarkUnread('inbox', key) DISABLED
-      indexMarkUnread('bookmarks', key)
-      indexMarkUnread('mentions', key)
-      indexMarkUnread('privatePosts', key)
-      indexMarkUnread('follows', key)
+      indexMarkUnread('inbox', key)
+      // indexMarkUnread('bookmarks', key)
+      // indexMarkUnread('mentions', key)
+      // indexMarkUnread('privatePosts', key)
+      // indexMarkUnread('follows', key)
       if (Array.isArray(key)) {
         db.isread.batch(key.map(function (k) { return { type: 'del', key: k }}), cb)
         key.forEach(function (key) { emit('isread', { key: key, value: false }) })
@@ -489,12 +488,12 @@ exports.init = function (sbot, opts) {
   api.getNamesById = function (cb) {
     awaitSync(function () { cb(null, state.names) })
   }
-  api.getName = function (id, cb) {
-    awaitSync(function () { cb(null, state.names[id]) })
-  }
   api.getIdsByName = function (cb) {
     awaitSync(function () { cb(null, state.ids) })
   }
+  api.getName = function (id, cb) {
+    awaitSync(function () { cb(null, state.names[id]) })
+  }
   api.getActionItems = function (cb) {
     awaitSync(function () { cb(null, state.actionItems) })
   }
