@@ -52,10 +52,10 @@ export default class LeftNav extends React.Component {
   }
 
   static Heading (props) {
-    return <div className="leftnav-heading">{props.children}</div>
+    return <div className="heading">{props.children}</div>
   }
   static Link (props) {
-    return <div className={'leftnav-link '+(props.className||'')+(props.pathname === props.to ? ' selected' : '')}>
+    return <div className={'link '+(props.className||'')+(props.pathname === props.to ? ' selected' : '')}>
       <Link to={props.to}>{props.children}</Link>
     </div>
   }
@@ -67,34 +67,33 @@ export default class LeftNav extends React.Component {
     const isPinned = b => channel => (!!channel.pinned == b)
     
     // lists
-    const pinnedChannels = this.state.channels.filter(isPinned(true))
-    const contacts = app.user.friends.map(id => ({ id: id, name: u.getName(id) })).sort((a, b) => a.name.localeCompare(b.name))
+    const pinnedChannels = this.state.channels.filter(isPinned(true)).sort((a, b) => a.name.localeCompare(b.name))
+    const unpinnedChannels = this.state.channels.filter(isPinned(false)).slice(0, 30)
 
     // render
     const renderChannel = c => <LeftNav.Link pathname={pathname} key={c.name} to={'/public/channel/'+c.name}><i className="fa fa-hashtag" /> {c.name}</LeftNav.Link>
-    const renderContact = c => <LeftNav.Link pathname={pathname} key={c.id} to={'/profile/'+encodeURIComponent(c.id)}><i className="fa fa-user" /> {c.name}</LeftNav.Link>
+    // const followUnread = (app.indexCounts.followUnread > 0) ? `(${app.indexCounts.followUnread})` : ''
     return <div className="leftnav">
-      <LeftNav.Link pathname={pathname} to="/"><i className="fa fa-comment-o" /> All talk</LeftNav.Link>
-      <LeftNav.Link pathname={pathname} to="/contacts"><i className="fa fa-users" /> Network</LeftNav.Link>
+      <LeftNav.Link pathname={pathname} to="/"><i className="fa fa-inbox" /> Inbox</LeftNav.Link>
+      <LeftNav.Link pathname={pathname} to="/inbox"><i className="fa fa-inbox" /> Important ({app.indexCounts.inboxUnread})</LeftNav.Link>
+      <LeftNav.Link pathname={pathname} to="/contacts"><i className="fa fa-users" /> Contacts</LeftNav.Link>
       <Issues/>
 
-      <LeftNav.Heading>Inbox</LeftNav.Heading>
+      {''/*<LeftNav.Heading>Inbox</LeftNav.Heading>
       <LeftNav.Link pathname={pathname} to="/private"><i className="fa fa-lock" /> Private ({app.indexCounts.privateUnread})</LeftNav.Link>
       <LeftNav.Link pathname={pathname} to="/bookmarks"><i className="fa fa-bookmark" /> Bookmarked ({app.indexCounts.bookmarkUnread})</LeftNav.Link>
       <LeftNav.Link pathname={pathname} to="/mentions"><i className="fa fa-at" /> Mentioned ({app.indexCounts.mentionUnread})</LeftNav.Link>
-      <LeftNav.Link pathname={pathname} to="/follows"><i className="fa fa-user-plus" /> Follows ({app.indexCounts.followUnread})</LeftNav.Link>
+      <LeftNav.Link pathname={pathname} to="/follows"><i className="fa fa-user-plus" /> Follows ({app.indexCounts.followUnread})</LeftNav.Link>*/}
 
-      <LeftNav.Heading>Channels</LeftNav.Heading>
+      <LeftNav.Heading>
+        Pinned Channels <a onClick={this.onOpenChannelList.bind(this)}><i className="fa fa-wrench" /></a>
+        { this.state.isChannelListOpen ? <i className="fa fa-caret-left" style={{ color: 'gray', marginLeft: 5 }} /> : '' }
+      </LeftNav.Heading>
       { pinnedChannels.map(renderChannel) }
-      <div className="leftnav-link">
-        <a onClick={this.onOpenChannelList.bind(this)}>Find more...</a>
-        { this.state.isChannelListOpen ? <i className="fa fa-caret-left" style={{ color: 'gray' }} /> : '' }
-      </div>
       { this.state.isChannelListOpen ? <ChannelList channels={this.state.channels} onSelect={this.onSelectChannel.bind(this)} /> : '' }
 
-      <LeftNav.Heading>Network</LeftNav.Heading>
-      { contacts.map(renderContact) }
-      <div className="leftnav-link"><Link to="/add-contact">Find more...</Link></div>
+      <LeftNav.Heading>Active Channels</LeftNav.Heading>
+      { unpinnedChannels.map(renderChannel) }
 
       <LeftNav.Heading>Tools</LeftNav.Heading>
       <LeftNav.Link pathname={pathname} to="/sync"><i className="fa fa-cloud-download" /> Network Sync</LeftNav.Link>
