@@ -122,8 +122,9 @@ function onPatchworkEvent (e) {
     for (var k in e.counts)
       app.indexCounts[k] = e.counts[k]
     app.emit('update:indexCounts')
+    updateTitle()
     if (e.index.indexOf('channel-') === 0) {
-      updateChannels(e.index.slice('channel-'.length), { lastUpdated: Date.now() }) // TODO hasNew
+      updateChannels(e.index.slice('channel-'.length), { lastUpdated: Date.now() })
       app.emit('update:channels')      
     }
   }
@@ -148,6 +149,10 @@ function pollPeers () {
   })
 }
 
+function updateTitle () {
+  document.title = '('+app.indexCounts.inboxUnread+') Patchwork'
+}
+
 function fetchLatestState (cb) {
   if (!patchworkEventStream)
     pull((patchworkEventStream = app.ssb.patchwork.createEventStream()), pull.drain(onPatchworkEvent.bind(this)))
@@ -180,6 +185,7 @@ function fetchLatestState (cb) {
     app.isWifiMode      = require('./util').getPubStats(app.peers).hasSyncIssue
     app.user.profile    = app.users.profiles[app.user.id]
     app.user.needsSetup = !app.users.names[app.user.id]
+    updateTitle()
 
     // get friend list
     var social = require('./social-graph')
@@ -192,7 +198,7 @@ function fetchLatestState (cb) {
     app.suggestOptions['@'] = []
     if (app.user.profile) {
       for (var id in app.users.profiles) {
-        if (id == app.user.profile.id || (app.user.profile.assignedTo[id] && app.user.profile.assignedTo[id].following)) {
+        if (id == app.user.profile.id || social.follows(app.user.id, id)) {
           var name = app.users.names[id]
           app.suggestOptions['@'].push({
             id: id,
