@@ -1,10 +1,11 @@
 'use babel'
 import React from 'react'
-import UserList from '../com/user-list'
+import { VerticalFilledContainer } from '../com'
+import UserView from '../com/user/view'
 
 export default class Profile extends React.Component {
   render() {
     const pid = (this.props.params.id) ? decodeURIComponent(this.props.params.id) : false
-    return <div id="profile"><UserList selected={pid} /></div>
+    return <div id="profile"><UserView pid={pid} location={this.props.location} /></div>
   }
 }
\ No newline at end of file
